==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebGridToolbarPinningDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseToolbarColumnActionsDirectiveDescriptionMetadata } from "./WebBaseToolbarColumnActionsDirectiveDescriptionMetadata";
import { WebGridToolbarPinningDescription } from "./WebGridToolbarPinningDescription";
/**
 * @hidden
 */
var WebGridToolbarPinningDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridToolbarPinningDescriptionMetadata, _super);
    function WebGridToolbarPinningDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridToolbarPinningDescriptionMetadata.b = function (a) {
        if (WebGridToolbarPinningDescriptionMetadata.a == null) {
            WebGridToolbarPinningDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridToolbarPinningDescriptionMetadata.c(WebGridToolbarPinningDescriptionMetadata.a);
        }
        if (a.k(WebGridToolbarPinningDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebGridToolbarPinningDescriptionMetadata.a);
    };
    WebGridToolbarPinningDescriptionMetadata.c = function (a) {
        WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:GridToolbarPinning");
        a.item("__tagNameWC", "String:igc-grid-toolbar-pinning");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        if (a.containsKey("__skipSuffix")) {
            a.removeItem("__skipSuffix");
        }
        a.item("__manageItemInMarkup", "Boolean");
    };
    WebGridToolbarPinningDescriptionMetadata.d = function (a) {
        WebGridToolbarPinningDescriptionMetadata.b(a);
        a.ad("WebGridToolbarPinning", function () { return new WebGridToolbarPinningDescription(); });
        a.ac("WebGridToolbarPinning", WebGridToolbarPinningDescriptionMetadata.a);
    };
    WebGridToolbarPinningDescriptionMetadata.$t = markType(WebGridToolbarPinningDescriptionMetadata, 'WebGridToolbarPinningDescriptionMetadata');
    WebGridToolbarPinningDescriptionMetadata.a = null;
    return WebGridToolbarPinningDescriptionMetadata;
}(Base));
export { WebGridToolbarPinningDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebGridToolbarPinningDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseToolbarColumnActionsDirectiveDescriptionMetadata } from "./WebBaseToolbarColumnActionsDirectiveDescriptionMetadata";
import { WebGridToolbarPinningDescription } from "./WebGridToolbarPinningDescription";
/**
 * @hidden
 */
var WebGridToolbarPinningDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridToolbarPinningDescriptionMetadata, _super);
    function WebGridToolbarPinningDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridToolbarPinningDescriptionMetadata.b = function (a) {
        if (WebGridToolbarPinningDescriptionMetadata.a == null) {
            WebGridToolbarPinningDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridToolbarPinningDescriptionMetadata.c(WebGridToolbarPinningDescriptionMetadata.a);
        }
        if (a.k(WebGridToolbarPinningDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebGridToolbarPinningDescriptionMetadata.a);
    };
    WebGridToolbarPinningDescriptionMetadata.c = function (a) {
        WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:GridToolbarPinning");
        a.item("__tagNameWC", "String:igc-grid-toolbar-pinning");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        if (a.containsKey("__skipSuffix")) {
            a.removeItem("__skipSuffix");
        }
        a.item("__manageItemInMarkup", "Boolean");
    };
    WebGridToolbarPinningDescriptionMetadata.d = function (a) {
        WebGridToolbarPinningDescriptionMetadata.b(a);
        a.ae("WebGridToolbarPinning", function () { return new WebGridToolbarPinningDescription(); });
        a.ad("WebGridToolbarPinning", WebGridToolbarPinningDescriptionMetadata.a);
    };
    WebGridToolbarPinningDescriptionMetadata.$t = markType(WebGridToolbarPinningDescriptionMetadata, 'WebGridToolbarPinningDescriptionMetadata');
    WebGridToolbarPinningDescriptionMetadata.a = null;
    return WebGridToolbarPinningDescriptionMetadata;
}(Base));
export { WebGridToolbarPinningDescriptionMetadata };
